@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """ ai.helper """
-
 import argparse
 import os
 import re
@@ -472,7 +471,6 @@ def readlines(filepath, start=0, n=None):
 class AverageMeter(object):
     """ Computes and stores the average and current value
     """
-
     def __init__(self):
         self.reset()
 
@@ -496,8 +494,8 @@ def remove_punc(text):
 
 
 def search(pattern, sequence):
-    """从 sequence 中寻找子串 pattern
-    如果找到，返回第一个下标；否则返回-1。
+    """ 从 sequence 中寻找子串 pattern
+    如果找到，返回第一个下标；否则返回 -1。
     """
     n = len(pattern)
     for i in range(len(sequence)):
@@ -506,6 +504,18 @@ def search(pattern, sequence):
     return -1
 
 
+def search_all(pattern, sequence):
+    """ 从 sequence 中寻找子串 pattern
+    如果找到，返回所有起始坐标；否则返回 []。
+    """
+    res = []
+    n = len(pattern)
+    for i in range(len(sequence)):
+        if sequence[i:i + n] == pattern:
+            res.append([i, i+n-1])
+    return res
+
+
 def str2bool(v):
     if v.lower() in ('yes', 'true', 't', 'y', '1'):
         return True
